// Copyright © 2002 Elliotte Rusty Harold
// 
// This library is free software; you can redistribute it and/or
// modify it under the terms of version 2.1 of 
// the GNU Lesser General Public License as published by the 
// Free Software Foundation.
// 
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
// 
// You can contact Elliotte Rusty Harold by sending e-mail to
// elharo@metalab.unc.edu. Please include the word "XOM" in the
// subject line. The XOM home page is temporarily located at
// http://www.cafeconleche.org/XOM/  but will eventually move
// to http://www.xom.nu/

package nu.xom;

/**
 * <p>
 *  This class represents the leaf nodes in an XML document;
 * i.e. those tree nodes that cannot have children:
 * </p>
 * 
 * <ul>
 *   <li>Text</li>
 *   <li>Comment</li>
 *   <li>ProcessingInstruction</li>
 * </ul>
 * 
 * <p>
 * Does this class really need to be public? I can't imagine why. 
 * </p>
 * 
 * @author Elliotte Rusty Harold
 * @version 1.0d2
 * 
 *
 */
abstract class LeafNode extends TreeNode {

    /**
     * Returns false because leaf nodes do not have children.
     * 
     * @return false
     * @see nu.xom.TreeNode#hasChildren()
     */
    public final boolean hasChildren() {
        return false;   
    }
    
    /**
     * Returns null because leaf nodes do not have children.
     * 
     * @return null
     * @see nu.xom.TreeNode#getFirstChild()
     */
    public final TreeNode getFirstChild() {
        return null;    
    }

    /**
     * Throws <code>IndexOutOfBoundsException</code> because leaf nodes do not have children.
     * 
     * @throws IndexOutOfBoundsException because leaf nodes do not have children.
     */
    public final TreeNode getChild(int position) {
        throw new IndexOutOfBoundsException("LeafNodes do not have children");        
    }

    /**
     * Returns 0 because leaf nodes do not have children.
     * 
     * @return zero
     * @see nu.xom.TreeNode#getChildCount()
     */
    public final int getChildCount() {
        return 0;   
    }

    /**
     * Throws <code>IllegalAddException<code> because leaf nodes cannot have children.
     * 
     * @throws IllegalAddException because leaf nodes do not have children.
     */
    public final void insertChild(int position, TreeNode child) {
        throw new IllegalAddException("LeafNodes cannot have children");        
    }

}
