package nu.xom.samples;

import java.io.*;
import java.util.*;
import nu.xom.Element;
import nu.xom.Document;
import nu.xom.Serializer;
import nu.xom.Attribute;

public class AttributesXMLBudget {

  public static void convert(List data, OutputStream out) 
   throws IOException {
      
	Element budget = new Element("Budget");
    Document doc = new Document(budget);
          
    Iterator records = data.iterator();
    while (records.hasNext()) {
      Element lineItem = new Element("LineItem");
      Map record = (Map) records.next();

      // write the attributes
      setYear(lineItem, "AgencyCode", record);
      setYear(lineItem, "AgencyName", record);
      setYear(lineItem, "BureauCode", record);
      setYear(lineItem, "BureauName", record);
      setYear(lineItem, "AccountCode", record);
      setYear(lineItem, "AccountName", record);
      setYear(lineItem, "TreasuryAgencyCode", record);
      setYear(lineItem, "SubfunctionCode", record);
      setYear(lineItem, "SubfunctionTitle", record);
      setYear(lineItem, "BEACategory", record);
      setYear(lineItem, "BudgetIndicator", record);
      setAmount(lineItem, "1976", record);
      Element amount = new Element("Amount");
      amount.add(new Attribute("year", "TransitionalQuarter"));    
      amount.appendChild((String) record.get("TransitionalQuarter"));
      for (int year=1977; year <= 2006; year++) {
        setAmount(lineItem, String.valueOf(year), record);
      }
    }

	Serializer serializer = new Serializer(out, "UTF-8");
    serializer.write(doc);
    serializer.flush();
        
  } 

  // Convert ListItem to LineItem in 4.4 in xmljava????

  // Just a couple of private methods to factor out repeated code 
  private static void setYear(Element element, String name, 
   Map record) throws IOException {
    element.add(new Attribute(name, (String) record.get(name)));       
  }

  private static void setAmount(Element element, String year, 
   Map record) throws IOException {
    Element amount = new Element("Amount");
    amount.add(new Attribute("year", String.valueOf(year)));    
    amount.appendChild((String) record.get("Y" + year));
    element.appendChild(amount);
  }

  public static void main(String[] args) {
  
    try {
        
      if (args.length < 1) {
        System.out.println(
         "Usage: AttributesXMLBudget infile outfile"
        );
        return;
      }
      
      InputStream in = new FileInputStream(args[0]); 
      OutputStream out; 
      if (args.length < 2) {
        out = System.out;
      }
      else {
        out = new FileOutputStream(args[1]); 
      }

      List results = BudgetData.parse(in);
      convert(results, out);
    }
    catch (IOException e) {
      System.err.println(e);       
    }
  
  }

}
