package nu.xom.samples;

import java.net.*;
import java.io.*;
import nu.xom.Element;
import nu.xom.Document;
import nu.xom.Serializer;
import nu.xom.Builder;
import nu.xom.ParseException;


public class FibonacciXMLRPCClient {
  
  private static String defaultServer 
   = "http://www.elharo.com/fibonacci/XML-RPC";
   
  public static void main(String[] args) {

    if (args.length == 0) {
      System.out.println(
       "Usage: java FibonacciXMLRPCClient index serverURL"); 
      return;
    }
    
    String index = args[0];
    
    String server;
    if (args.length <= 1) server = defaultServer;
    else server = args[1];
    
    try {
        URL u = new URL(server);
        URLConnection uc = u.openConnection();
        HttpURLConnection connection = (HttpURLConnection) uc;
        connection.setDoOutput(true);
        connection.setDoInput(true); 
        connection.setRequestMethod("POST");
        OutputStream out = connection.getOutputStream();
      
		Element methodCall = new Element("methodCall");
		Element methodName = new Element("methodName");
		methodName.appendChild("calculateFibonacci");
 		Element params = new Element("params");
		Element param = new Element("param");
		Element value = new Element("value");
		Element data = new Element("int");
		data.appendChild(index);
        methodCall.appendChild(methodName); 
        methodCall.appendChild(params); 
        params.appendChild(param);
        param.appendChild(value);
        value.appendChild(data);
      	Document doc = new Document(methodCall);

		Serializer serializer = new Serializer(out, "US-ASCII");
      	serializer.write(doc);
      	
      	InputStream in = connection.getInputStream();
      	
      	Builder parser = new Builder();
      	Document response = parser.build(in);

      	in.close();
      	out.close();
      	connection.disconnect();

		// Need to handle faults????
		// specifically bad user input????
		// negative and/or words????
      	Element methodResponse = response.getRootElement();      	
      	Element responseParams = methodResponse.getFirstChildElement("params");
      	Element responseParam = responseParams.getFirstChildElement("param");
      	Element responseValue = responseParam.getFirstChildElement("value");
      	Element responseDouble = responseValue.getFirstChildElement("double");		
  
      	System.out.println(responseDouble.getValue());
      	
    }
    catch (ParseException ex) {
      System.err.println("Server sent malformed output"); 
      System.err.println(ex); 
    }
    catch (NullPointerException ex) {
      System.err.println("Server sent invalid output without the expected content."); 
      System.err.println(ex); 
    }
    catch (IOException ex) {
      System.err.println(ex); 
    }
  
  }  // end main

}