package nu.xom.samples;

/**
 * @author Elliotte Rusty Harold
 *
 */
import nu.xom.Element;
import nu.xom.Builder;
import nu.xom.Document;
import nu.xom.TreeNode;
import nu.xom.ParseException;
import java.io.IOException;


public class NodeLister {

  public static void main(String[] args) {
  
    if (args.length == 0) {
      System.out.println("Usage: java NodeLister URL"); 
      return;
    } 
      
    Builder builder = new Builder();
     
    try {
      Document doc = builder.build(args[0]);
      Element root = doc.getRootElement();
      listChildren(root, 0);      
    }
    // indicates a well-formedness error
    catch (ParseException e) { 
      System.out.println(args[0] + " is not well-formed.");
      System.out.println(e.getMessage());
    }  
    catch (IOException e) { 
      System.out.println(e);
    }  
  
  }
  
  
  public static void listChildren(TreeNode current, int depth) {
   
    printSpaces(depth);
    String name = "";
    if (current instanceof Element) {
        Element temp = (Element) current;
        name = ": " + temp.getQualifiedName();   
    }
    System.out.println(current.getClass().getName() + name);
    for (int i = 0; i < current.getChildCount(); i++) {
      listChildren(current.getChild(i), depth+1);
    }
    
  }
  
  private static void printSpaces(int n) {
    
    for (int i = 0; i < n; i++) {
      System.out.print(' '); 
    }
    
  }

}
