package nu.xom.samples;

import java.io.IOException;

import nu.xom.Document;
import nu.xom.Element;
import nu.xom.Builder;
import nu.xom.Elements;
import nu.xom.ParseException;
import nu.xom.Serializer;
import nu.xom.TreeNode;

/**
 * @author Elliotte Rusty Harold
 *
 */
public class RDDLStripper {

    public final static String RDDL_NAMESPACE 
       = "http://www.rddl.org/";

	public static void main(String[] args) {

        if (args.length <= 0) {
          System.out.println("Usage: java RDDLStripper URL");
          return;
        }
        
        try {
            Builder parser = new Builder();
            Document doc = parser.build(args[0]);
          
            strip(doc.getRootElement());
          

            System.out.println(doc.getStringForm());
        }
        catch (ParseException ex) {
          System.out.println(args[0] + " is not well-formed.");
          System.out.println(ex.getMessage());
        }
        catch (IOException ex) { 
          System.out.println(
           "Due to an IOException, the parser could not read " 
           + args[0]
          ); 
        }      
        
	}
    
    public static void strip(Element element) {
        
       if (element.getNamespaceURI().equals(RDDL_NAMESPACE)) {
            
            TreeNode parent = element.getParent();
            int position = 0;
            for (; position < parent.getChildCount(); position++) {
                if (parent.getChild(position) == element) break;
            }
            parent.removeChild(position);
            while (element.getChildCount() > 0) {
                TreeNode child = element.getFirstChild();
                // Might be helpful to make removeChild() return the thing it removes????
                element.removeChild(0);
                parent.insertChild(position, child);
                position++;
                if (child instanceof Element) strip((Element) child);
            }     
            
        }
        else {
            Elements elements = element.getChildElements();      
            for (int i = 0; i < elements.size(); i++) {
                strip(elements.get(i));
            }     
        }       
        
    } 
    
}