package nu.xom.samples;

/**
 * @author Elliotte Rusty Harold
 *
 */
import nu.xom.TreeNode;
import nu.xom.Comment;
import nu.xom.ProcessingInstruction;
import nu.xom.Document;
import nu.xom.Builder;
import nu.xom.ParseException;
import java.io.IOException;




public class Restructurer {

    // Since this methods only operates on its argument and does
    // not interact with any fields in the class, it's 
    // plausibly made static.
    public static void processNode(TreeNode current) {
    
    
        // I need to store a reference to the current node's next
        // sibling before we delete the node from the tree, in which
        // case it no longer has a sibling
        TreeNode nextSibling = current.getNextSibling();
    
        if (current instanceof Comment || current instanceof ProcessingInstruction) {       
            Document document = current.getDocument();
            TreeNode root = document.getRootElement();
            current.detach();
            document.insertBefore(root, current);      
        }
        else if (current.hasChildren()) {
            TreeNode firstChild = current.getFirstChild();
            processNode(firstChild);
        }
    
        if (nextSibling != null) {
            processNode(nextSibling);
        }
    
  }

    public static void main(String[] args) {
     
        if (args.length <= 0) {
            System.out.println("Usage: java RestructureDriver URL");
            return;
        }
        String url = args[0];
    
        try {
            // Find a parser
            Builder parser = new Builder();
      
            // Read the document
            Document document = parser.build(url); 
     
            // Modify the document
            Restructurer.processNode(document.getRootElement());
      
            // Write it out again
            System.out.println(document.getStringForm());
      
        }
        catch (ParseException e) {
            System.out.println(url + " is not well-formed.");
        }
        catch (IOException e) { 
            System.out.println(
             "Due to an IOException, the parser could not read " + url); 
        }
   
    }


}


