package nu.xom.samples;

/**
 * @author Elliotte Rusty Harold
 *
 */
import nu.xom.Element;
import nu.xom.Builder;
import nu.xom.Document;
import nu.xom.Elements;
import nu.xom.ParseException;
import nu.xom.Attribute;
import nu.xom.Attributes;
import nu.xom.Namespaces;
import java.io.IOException;


public class TreePrinter {

  public static void main(String[] args) {
  
    if (args.length == 0) {
      System.out.println("Usage: java TreePrinter URL"); 
      return;
    } 
      
    Builder builder = new Builder();
     
    try {
      Document doc = builder.build(args[0]);
      Element root = doc.getRootElement();
      listChildren(root);      
    }
    // indicates a well-formedness error
    catch (ParseException e) { 
      System.out.println(args[0] + " is not well-formed.");
      System.out.println(e.getMessage());
    }  
    catch (IOException e) { 
      System.out.println(e);
    }  
  
  }
  

  // Print the properties of each element
  public static void inspect(Element element) {
    
    if (element.getParent() != null) {
      // Print a blank line to separate it from the previous
      // element.
      System.out.println(); 
    }
    
    String qualifiedName = element.getQualifiedName();
    System.out.println(qualifiedName + ":");
    
    String namespace = element.getNamespaceURI();
    if (!namespace.equals("")) {
      String localName = element.getLocalName();
      String uri = element.getNamespaceURI();
      String prefix = element.getNamespacePrefix();
      System.out.println("  Local name: " + localName);
      System.out.println("  Namespace URI: " + uri);
      if (!"".equals(prefix)) {
        System.out.println("  Namespace prefix: " + prefix);
      }
    }
    Attributes attributes = element.getAttributes();
    for (int i = 0; i < attributes.size(); i++) {
        Attribute attribute = attributes.get(i);
        String name = attribute.getQualifiedName();
        String value = attribute.getValue();
        System.out.println("  " + name + "=\"" + value + "\""); 
    }
    
    Namespaces namespaces = element.getAdditionalNamespaces();
    for (int i = 0; i < namespaces.size(); i++) {
        String additional = namespaces.getPrefix(i);
        String uri = namespaces.getURI(additional);
        System.out.println(
          "  xmlns:" + additional + "=\"" + uri + "\""); 
    }
    
  }
  
  public static void listChildren(Element current) {
   
    inspect(current);
    Elements children = current.getChildElements();
    for (int i = 0; i < children.size(); i++) {
      listChildren(children.get(i));
    }
    
  }

}
