package nu.xom.samples;

import java.io.IOException;

import nu.xom.Document;
import nu.xom.Element;
import nu.xom.Builder;
import nu.xom.Elements;
import nu.xom.ParseException;
import nu.xom.Serializer;
import nu.xom.TreeNode;
import nu.xom.Attributes;
import nu.xom.Attribute;
import nu.xom.Namespaces;

/**
 * <p>
 *   This is a simple program to strip out all non
 *   XHTML elements and their content from a document.
 * </p>
 * 
 * @author Elliotte Rusty Harold
 *
 */
public class XHTMLPurifier {

     public final static String XHTML_NAMESPACE 
       = "http://www.w3.org/1999/xhtml";

    public static void main(String[] args) {

        if (args.length <= 0) {
          System.out.println("Usage: java XHTMLPurifier URL");
          return;
        }
        
        try {
            Builder parser = new Builder();
            Document doc = parser.build(args[0]);
            Element root = doc.getRootElement();
            if (root.getNamespaceURI().equals(XHTML_NAMESPACE)) {
                strip(root);
            }
            else {
                System.out.println(args[0] + " does not appear to be an XHTML document");
                return;   
            }
          

            System.out.println(doc.getStringForm());
        }
        catch (ParseException ex) {
          System.out.println(args[0] + " is not well-formed.");
          System.out.println(ex.getMessage());
        }
        catch (IOException ex) { 
          System.out.println(
           "Due to an IOException, the parser could not read " 
           + args[0]
          ); 
        }      
        
    }
    
    public static void strip(Element element) {
        
       if (element.getNamespaceURI().equals(XHTML_NAMESPACE)) {
            
            // Strip out non XHTML attributes
            Attributes atts = element.getAttributes();
            for (int i = 0; i < atts.size(); i++) {
               Attribute attribute = atts.get(i);
               
               if (!"".equals(attribute.getNamespaceURI())) {
                  if (!"xml".equals(attribute.getNamespacePrefix())) {
                       attribute.detach();
                  }
               } 
            }
            
            // Strip out addditional namespaces
            Namespaces namespaces = element.getAdditionalNamespaces();
            for (int i = 0; i < namespaces.size(); i++) {
                String prefix = namespaces.getPrefix(i);
                element.removeNamespaceDeclaration(prefix);  
            }
            
            Elements elements = element.getChildElements();      
            for (int i = 0; i < elements.size(); i++) {
                strip(elements.get(i));
            }     
            
        }
        else {
            element.detach();     
        }       
        
    } 
    
}