/* Copyright © 2002 Elliotte Rusty Harold
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of version 2.1 of 
   the GNU Lesser General Public License as published by the 
   Free Software Foundation.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   
   You can contact Elliotte Rusty Harold by sending e-mail to
   elharo@metalab.unc.edu. Please include the word "XOM" in the
   subject line. The XOM home page is temporarily located at
   http://www.cafeconleche.org/XOM/  but will eventually move
   to http://www.xom.nu/  
*/

package nu.xom.tests;

import junit.framework.Assert;
import junit.framework.TestCase;

import nu.xom.Attribute;
import nu.xom.Attributes;
import nu.xom.Element;

/**
 * @author Elliotte Rusty Harold
 *
 */
public class AttributesTest extends TestCase {

    public AttributesTest() {
        super("Attribute tests");
    }

    public AttributesTest(String name) {
        super(name);
    }

    Attributes  threeAttributes;
    Attributes  noAttributes;


    protected void setUp() {
        Element element = new Element("test");
        noAttributes = element.getAttributes();
        Element element2 = new Element("test");
        element2.add(new Attribute("att1", "value1"));
        element2.add(new Attribute("att2", "value2"));
        element2.add(new Attribute("att3", "value3"));
        threeAttributes = element2.getAttributes();
    }

    public void testSize() {
        Assert.assertEquals(0, noAttributes.size());
        Assert.assertEquals(3, threeAttributes.size());
     }

   public void testGetOutOfBounds() {
    
        try {
            Assert.assertNull(noAttributes.get(0));
            fail("Should have thrown IndexOutOfBoundsException");
        }
        catch (IndexOutOfBoundsException ex) {
            // success   
        }
        try {
            Assert.assertNull(threeAttributes.get(4));
        }
        catch (IndexOutOfBoundsException ex) {
            // success   
        }
        try {
            Assert.assertNull(threeAttributes.get(-1));
                }
        catch (IndexOutOfBoundsException ex) {
            // success   
        }

     }


    public void testGetByName() {
        Assert.assertEquals("value1", threeAttributes.get("att1").getValue());
        Assert.assertNull(threeAttributes.get("notInList"));
    }



}