/* Copyright © 2002 Elliotte Rusty Harold
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of version 2.1 of 
   the GNU Lesser General Public License as published by the 
   Free Software Foundation.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   
   You can contact Elliotte Rusty Harold by sending e-mail to
   elharo@metalab.unc.edu. Please include the word "XOM" in the
   subject line. The XOM home page is temporarily located at
   http://www.cafeconleche.org/XOM/  but will eventually move
   to http://www.xom.nu/  
*/

package nu.xom.tests;

import junit.framework.TestCase;
import java.io.Reader;
import java.io.StringReader;
import java.io.IOException;

import nu.xom.DocType;
import nu.xom.Document;
import nu.xom.Element;
import nu.xom.Comment;
import nu.xom.ProcessingInstruction;
import nu.xom.Builder;
import nu.xom.ParseException;


/**
 * @author Elliotte Rusty Harold
 *
 */
public class BuilderTest extends TestCase {

    public BuilderTest(String name) {
        super(name);   
    }

    private String source = "<!DOCTYPE test>\r\n"
     + "<?xml-stylesheet href=\"file.css\" type=\"text/css\"?>" 
     + "<!-- test -->"
     + "<test xmlns:xlink='http://www.w3.org/TR/1999/xlink'>Hello dear"
     + "\r\n<em id=\"p1\" xmlns:none=\"http://www.example.com\">very important</em>"
     + "<span xlink:type='simple'>here&apos;s the link</span>\r\n"
     + "<svg:svg xmlns:svg='http://www.w3.org/TR/2000/svg'><svg:text>text in a namespace</svg:text></svg:svg>\r\n"
     + "<svg xmlns='http://www.w3.org/TR/2000/svg'><text>text in a namespace</text></svg>"
     + "</test>\r\n"
     + "<!--epilog-->";
     
    private Builder builder = new Builder();
    private Document document;


    protected void setUp() {
        
        Reader reader = new StringReader(source);
        
        
        try {
            document = builder.build(reader);
        }
        catch (IOException ex) {
            // shouldn't happen from StringReader   
        }
        catch (ParseException ex) {
            // shouldn't happen from known good doc 
            /* System.out.println("Line: " + ex.getLineNumber());
            System.out.println("Column: " + ex.getColumnNumber());
            System.out.println(ex.getCause().getClass().getName()); */
            throw new RuntimeException("Oops! " + ex.getMessage());  
        }
 
     }

    public void testBuiltDocument() {
        
        assertTrue(document.getFirstChild().getNextSibling() instanceof ProcessingInstruction);
        assertTrue(document.getFirstChild().getNextSibling().getNextSibling() instanceof Comment);        
        DocType doctype = document.getDocType();
        Element root = document.getRootElement();

        assertEquals(root.getQualifiedName(), "test");
        assertEquals(root.getLocalName(), "test");
        assertEquals(root.getNamespaceURI(), "");
        
        assertTrue(doctype != null);
        assertTrue(document.getFirstChild() instanceof DocType);
        assertTrue(root.getNextSibling() instanceof nu.xom.Comment);
        assertTrue(root.getPreviousSibling() instanceof nu.xom.Comment);
        assertEquals(root.getPreviousSibling().getValue(), " test ");
        assertEquals(root.getNextSibling().getValue(), "epilog");
        assertTrue(doctype.getNextSibling() instanceof nu.xom.ProcessingInstruction);
        assertEquals(doctype.getRootElementName(), "test");
        assertNull(doctype.getPublicID());
        assertNull(doctype.getSystemID());
        
       
    }


}
