/* Copyright © 2002 Elliotte Rusty Harold
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of version 2.1 of 
   the GNU Lesser General Public License as published by the 
   Free Software Foundation.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   
   You can contact Elliotte Rusty Harold by sending e-mail to
   elharo@metalab.unc.edu. Please include the word "XOM" in the
   subject line. The XOM home page is temporarily located at
   http://www.cafeconleche.org/XOM/  but will eventually move
   to http://www.xom.nu/  
*/

package nu.xom.tests;

import junit.framework.TestCase;
import nu.xom.Text;
import nu.xom.IllegalAddException;
import nu.xom.NoSuchChildException;


/**
 * @author Elliotte Rusty Harold
 *
 */
public class LeafNodeTest extends TestCase {

    public LeafNodeTest(String name) {
        super(name);
    }
    
    private Text parent;
    private Text child;
    
    protected void setUp() {
        child = new Text("child");
        parent = new Text("parent");
    }
    
    public void testHasChildren() {      
        assertTrue(!parent.hasChildren());       
    } 

    public void testAppendChild() {
        
        try {
            parent.appendChild(child);
            fail("added child to leaf node");
        }
        catch (IllegalAddException ex) {
            // success
        }
        assertTrue(!parent.hasChildren());
    } 

    public void testGetChild() {

        try {
            parent.getChild(0);
            fail("No index exception");   
        }
        catch (IndexOutOfBoundsException ex) {
            // success
        }

    } 

   public void testRemoveChild() {
        
        try {
            parent.removeChild(0);
            fail("No index exception");   
        }
        catch (IndexOutOfBoundsException ex) {
            // success
        }

    } 

    public void testInsertBefore() {
        
        try {
           parent.insertBefore(new Text("test"), new Text("sjhj"));
           fail("Inserted before element not in tree");
        }
        catch (NoSuchChildException ex) {
            // success   
        }
        

    } 

}
