/* Copyright © 2002 Elliotte Rusty Harold
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of version 2.1 of 
   the GNU Lesser General Public License as published by the 
   Free Software Foundation.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   
   You can contact Elliotte Rusty Harold by sending e-mail to
   elharo@metalab.unc.edu. Please include the word "XOM" in the
   subject line. The XOM home page is temporarily located at
   http://www.cafeconleche.org/XOM/  but will eventually move
   to http://www.xom.nu/  
*/

package nu.xom.tests;

import junit.framework.Assert;
import junit.framework.TestCase;

import nu.xom.Element;
import nu.xom.Namespaces;

/**
 * @author Elliotte Rusty Harold
 * @version 1.0d2
 *
 */
public class NamespacesTest extends TestCase {

    public NamespacesTest() {
        super("Namespaces tests");
    }

    public NamespacesTest(String name) {
        super(name);
    }

    private Namespaces someNamespaces;
    private Namespaces noNamespaces;


    protected void setUp() {
        Element element = new Element("test");
        noNamespaces = element.getAdditionalNamespaces();
        
        // List is dead
        element.addNamespaceDeclaration("xlink", 
         "http://www.w3.org/TR/2001/xlink");
        element.addNamespaceDeclaration("xsl", 
         "http://www.w3.org/TR/1999/xslt");
        someNamespaces = element.getAdditionalNamespaces();
        
    }

    public void testSize() {
        Assert.assertEquals(0, noNamespaces.size());
        Assert.assertEquals(2, someNamespaces.size());
     }


   public void testGetByPrefix() {
    
        Assert.assertEquals("http://www.w3.org/TR/2001/xlink", 
          someNamespaces.getURI("xlink"));
        Assert.assertEquals("http://www.w3.org/TR/1999/xslt", 
          someNamespaces.getURI("xsl"));
        Assert.assertNull(someNamespaces.getURI("fo"));
        Assert.assertNull(noNamespaces.getURI("xsl"));

     }



}